import { AddChildFromBuilder, Property, View as NSView, PercentLength, Style, CssProperty, PropertyChangeData } from '@nativescript/core';
export declare enum ParsedValueType {
    Auto = "auto",
    Px = "px",
    Dip = "dip",
    Percent = "%"
}
export interface ParsedValue {
    type: ParsedValueType;
    value: number;
}
export declare type SizeType = PercentLength | string;
export declare enum FlexDirection {
    Row = "row",
    RowReverse = "row-reverse",
    Column = "column",
    ColumnReverse = "column-reverse"
}
export declare enum FlexAlignSelf {
    Auto = "auto",
    FlexStart = "flex-start",
    FlexEnd = "flex-end",
    Center = "center",
    Stretch = "stretch",
    BaseLine = "baseline"
}
export declare enum FlexAlignItems {
    FlexStart = "flex-start",
    FlexEnd = "flex-end",
    Center = "center",
    Stretch = "stretch",
    BaseLine = "baseline"
}
export declare enum FlexJustify {
    FlexStart = "flex-start",
    Center = "center",
    FlexEnd = "flex-end",
    SpaceBetween = "space-between",
    SpaceAround = "space-around",
    SpaceEvenly = "space-evenly"
}
export declare enum FlexAlignContent {
    Stretch = "stretch",
    FlexStart = "flex-start",
    Center = "center",
    FlexEnd = "flex-end",
    SpaceBetween = "space-between",
    SpaceAround = "space-around"
}
export declare enum Overflow {
    Visible = "visible",
    Hidden = "hidden",
    Scroll = "scroll"
}
export declare enum Position {
    Relative = "relative",
    Absolute = "absolute"
}
export declare enum FlexWrap {
    Wrap = "wrap",
    NoWrap = "no-wrap",
    WrapReverse = "wrap-reverse"
}
export declare enum Direction {
    Inherit = "inherit",
    Ltr = "ltr",
    Rtl = "rtl"
}
export declare function toYGValue(value: SizeType): ParsedValue;
export declare abstract class ViewBase extends NSView implements AddChildFromBuilder {
    maxWidth: SizeType;
    maxHeight: SizeType;
    flex: number;
    flexDirection: FlexDirection;
    alignItems: FlexAlignItems;
    overflow: Overflow;
    position: Position;
    aspectRatio: number;
    left: any;
    top: any;
    right: any;
    bottom: any;
    start: any;
    end: any;
    direction: Direction;
    paddingHorizontal: any;
    paddingVertical: any;
    marginHorizontal: any;
    marginVertical: any;
    ios: any;
    android: any;
    yoga: any;
    yogaNode: any;
    abstract _addChildFromBuilder(name: string, value: any): void;
    abstract addChild(views: NSView): any;
    abstract addChildren(view: NSView[]): any;
    abstract removeChild(view: NSView): any;
    abstract getChildAt(index: number): NSView;
    abstract getChildIndex(view: NSView): number;
    abstract getChildrenCount(): number;
    abstract removeAllChildren(): any;
    _addPropertyChangeHandler(view: NSView): void;
    _removePropertyChangeHandler(view: NSView): void;
    _onPropertyChange(data: PropertyChangeData): void;
    _updateWidth(value: any, force?: boolean, json?: any, layout?: any): void;
    _updateHeight(value: any, force?: boolean, json?: any, layout?: any): void;
    _updateMinWidth(value: any, force?: boolean, json?: any, layout?: any): void;
    _updateMinHeight(value: any, force?: boolean, json?: any, layout?: any): void;
    _updateMaxWidth(value: any, force?: boolean, json?: any, layout?: any): void;
    _updateMaxHeight(value: any, force?: boolean, json?: any, layout?: any): void;
    _updateAlignItems(value: any, force?: boolean, json?: any, layout?: any): void;
    _updateOverflow(value: any, force?: boolean, json?: any, layout?: any): void;
    _updatePosition(value: any, force?: boolean, json?: any, layout?: any): void;
    _updateFlex(value: any, force?: boolean, json?: any, layout?: any): void;
    _updateFlexDirection(value: any, force?: boolean, json?: any, layout?: any): void;
    _setPositionValue(value: any, position: any, json?: any, layout?: any): void;
    _getPositionValue(position: any, layout?: any): "auto" | {
        value: any;
        unit: string;
    };
    _updateLeft(value: any, force?: boolean, json?: any, layout?: any): void;
    _updateTop(value: any, force?: boolean, json?: any, layout?: any): void;
    _updateRight(value: any, force?: boolean, json?: any, layout?: any): void;
    _updateBottom(value: any, force?: boolean, json?: any, layout?: any): void;
    _setPaddingValue(value: any, position: any, json?: any, layout?: any): void;
    _getPaddingValue(position: any, layout?: any): "auto" | {
        value: any;
        unit: string;
    };
    _updatePadding(value: any, force?: boolean, json?: any, layout?: any): void;
    _updatePaddingLeft(value: any, force?: boolean, json?: any, layout?: any): void;
    _updatePaddingTop(value: any, force?: boolean, json?: any, layout?: any): void;
    _updatePaddingRight(value: any, force?: boolean, json?: any, layout?: any): void;
    _updatePaddingBottom(value: any, force?: boolean, json?: any, layout?: any): void;
    _setMarginValue(value: any, position: any, json?: any, layout?: any): void;
    _getMarginValue(position: any, layout?: any): "auto" | {
        value: any;
        unit: string;
    };
    _updateMargin(value: any, force?: boolean, json?: any, layout?: any): void;
    _updateMarginLeft(value: any, force?: boolean, json?: any, layout?: any): void;
    _updateMarginTop(value: any, force?: boolean, json?: any, layout?: any): void;
    _updateMarginRight(value: any, force?: boolean, json?: any, layout?: any): void;
    _updateMarginBottom(value: any, force?: boolean, json?: any, layout?: any): void;
    _updateJustifyContent(value: any, force?: boolean, json?: any, layout?: any): void;
    _updateFlexWrap(value: any, force?: boolean, json?: any, layout?: any): void;
    _updateAlignSelf(value: any, force?: boolean, json?: any, layout?: any): void;
    _updateFlexGrow(value: any, force?: boolean, json?: any, layout?: any): void;
    _updateFlexShrink(value: any, force?: boolean, json?: any, layout?: any): void;
    _updateFlexBasis(value: any, force?: boolean, json?: any, layout?: any): void;
    _updateAlignContent(value: any, force?: boolean, json?: any, layout?: any): void;
    _updateAspectRatio(value: number, force?: boolean, json?: any, layout?: any): void;
    _setStartOrEnd(value: number, position: 'start' | 'end', force?: boolean, json?: any, layout?: any): void;
    _updateStart(value: number, force?: boolean, json?: any, layout?: any): void;
    _updateEnd(value: number, force?: boolean, json?: any, layout?: any): void;
    _updateDirection(value: Direction, force?: boolean, json?: any, layout?: any): void;
    _updateMarginVertical(value: any, force?: boolean, json?: any, layout?: any): void;
    _updateMarginHorizontal(value: any, force?: boolean, json?: any, layout?: any): void;
    _updatePaddingHorizontal(value: any, force?: boolean, json?: any, layout?: any): void;
    _updatePaddingVertical(value: any, force?: boolean, json?: any, layout?: any): void;
}
export declare const minWidthProperty: CssProperty<Style, SizeType>;
export declare const minHeightProperty: CssProperty<Style, SizeType>;
export declare const maxWidthProperty: CssProperty<Style, SizeType>;
export declare const maxHeightProperty: CssProperty<Style, SizeType>;
export declare const flexProperty: CssProperty<Style, number>;
export declare const flexDirectionProperty: CssProperty<Style, FlexDirection>;
export declare const flexGrowProperty: CssProperty<Style, number>;
export declare const flexShrinkProperty: CssProperty<Style, number>;
export declare const flexBasisProperty: CssProperty<Style, SizeType>;
export declare const alignContentProperty: CssProperty<Style, FlexAlignContent>;
export declare const alignItemsProperty: CssProperty<Style, FlexAlignItems>;
export declare const alignSelfProperty: CssProperty<Style, FlexAlignSelf>;
export declare const overflowProperty: CssProperty<Style, Overflow>;
export declare const positionProperty: CssProperty<Style, Position>;
export declare const leftProperty: CssProperty<Style, SizeType>;
export declare const topProperty: CssProperty<Style, SizeType>;
export declare const rightProperty: CssProperty<Style, SizeType>;
export declare const bottomProperty: CssProperty<Style, SizeType>;
export declare const justifyContentProperty: CssProperty<Style, FlexJustify>;
export declare const flexWrapProperty: CssProperty<Style, FlexWrap>;
export declare const aspectRatioProperty: Property<ViewBase, number>;
export declare const endProperty: CssProperty<Style, string | number>;
export declare const startProperty: CssProperty<Style, string | number>;
export declare const directionProperty: CssProperty<Style, Direction>;
export declare const paddingHorizontalProperty: CssProperty<Style, SizeType>;
export declare const paddingVerticalProperty: CssProperty<Style, SizeType>;
export declare const marginHorizontalProperty: CssProperty<Style, SizeType>;
export declare const marginVerticalProperty: CssProperty<Style, SizeType>;
declare module '@nativescript/core/ui/styling/style' {
    interface Style {
        left: any;
        top: any;
        right: any;
        bottom: any;
        start: any;
        end: any;
        marginVertical: any;
        marginHorizontal: any;
        paddingHorizontal: any;
        paddingVertical: any;
        justifyContent: any;
        maxWidth: any;
        maxHeight: any;
        flex: number;
        overflow: Overflow;
        position: Position;
        flexBasis: any;
        direction: Direction;
    }
}
export declare function _toYGFlexDirection(value: FlexDirection): any;
export declare function _toYGFlexAlignSelf(value: FlexAlignSelf): any;
export declare function _toYGFlexAlignItems(value: FlexAlignItems): any;
export declare function _toYGOverflow(value: Overflow): any;
export declare function _toYGPosition(value: Position): any;
export declare function _toNativeYG(value: any): any;
export declare function _toYGEdge(value: 'left' | 'top' | 'right' | 'bottom' | 'start' | 'end' | 'all' | 'vertical' | 'horizontal'): any;
export declare function _toYGFlexAlignContent(value: FlexAlignContent): any;
export declare function _toYGDirection(value: Direction): any;
