import { Property, View as NSView, Style, CssProperty } from '@nativescript/core';
import { layout as nsLayout } from '@nativescript/core/utils';
export var ParsedValueType;
(function (ParsedValueType) {
    ParsedValueType["Auto"] = "auto";
    ParsedValueType["Px"] = "px";
    ParsedValueType["Dip"] = "dip";
    ParsedValueType["Percent"] = "%";
})(ParsedValueType || (ParsedValueType = {}));
export var FlexDirection;
(function (FlexDirection) {
    FlexDirection["Row"] = "row";
    FlexDirection["RowReverse"] = "row-reverse";
    FlexDirection["Column"] = "column";
    FlexDirection["ColumnReverse"] = "column-reverse";
})(FlexDirection || (FlexDirection = {}));
export var FlexAlignSelf;
(function (FlexAlignSelf) {
    FlexAlignSelf["Auto"] = "auto";
    FlexAlignSelf["FlexStart"] = "flex-start";
    FlexAlignSelf["FlexEnd"] = "flex-end";
    FlexAlignSelf["Center"] = "center";
    FlexAlignSelf["Stretch"] = "stretch";
    FlexAlignSelf["BaseLine"] = "baseline";
})(FlexAlignSelf || (FlexAlignSelf = {}));
export var FlexAlignItems;
(function (FlexAlignItems) {
    FlexAlignItems["FlexStart"] = "flex-start";
    FlexAlignItems["FlexEnd"] = "flex-end";
    FlexAlignItems["Center"] = "center";
    FlexAlignItems["Stretch"] = "stretch";
    FlexAlignItems["BaseLine"] = "baseline";
})(FlexAlignItems || (FlexAlignItems = {}));
export var FlexJustify;
(function (FlexJustify) {
    FlexJustify["FlexStart"] = "flex-start";
    FlexJustify["Center"] = "center";
    FlexJustify["FlexEnd"] = "flex-end";
    FlexJustify["SpaceBetween"] = "space-between";
    FlexJustify["SpaceAround"] = "space-around";
    FlexJustify["SpaceEvenly"] = "space-evenly";
})(FlexJustify || (FlexJustify = {}));
export var FlexAlignContent;
(function (FlexAlignContent) {
    FlexAlignContent["Stretch"] = "stretch";
    FlexAlignContent["FlexStart"] = "flex-start";
    FlexAlignContent["Center"] = "center";
    FlexAlignContent["FlexEnd"] = "flex-end";
    FlexAlignContent["SpaceBetween"] = "space-between";
    FlexAlignContent["SpaceAround"] = "space-around";
})(FlexAlignContent || (FlexAlignContent = {}));
export var Overflow;
(function (Overflow) {
    Overflow["Visible"] = "visible";
    Overflow["Hidden"] = "hidden";
    Overflow["Scroll"] = "scroll";
})(Overflow || (Overflow = {}));
export var Position;
(function (Position) {
    Position["Relative"] = "relative";
    Position["Absolute"] = "absolute";
})(Position || (Position = {}));
export var FlexWrap;
(function (FlexWrap) {
    FlexWrap["Wrap"] = "wrap";
    FlexWrap["NoWrap"] = "no-wrap";
    FlexWrap["WrapReverse"] = "wrap-reverse";
})(FlexWrap || (FlexWrap = {}));
export var Direction;
(function (Direction) {
    Direction["Inherit"] = "inherit";
    Direction["Ltr"] = "ltr";
    Direction["Rtl"] = "rtl";
})(Direction || (Direction = {}));
export function toYGValue(value) {
    if (typeof value === 'string') {
        if (value === 'auto') {
            return { type: ParsedValueType.Auto, value: 0 };
        }
        else {
            const val = parseInt(value, 10);
            if (!isNaN(val)) {
                return { type: ParsedValueType.Dip, value: val };
            }
        }
    }
    else if (typeof value === 'number') {
        return { type: ParsedValueType.Dip, value };
    }
    else {
        if (value) {
            // @ts-ignore
            switch (value.unit) {
                case '%':
                    // @ts-ignore
                    return { type: ParsedValueType.Percent, value: value.value };
                case 'px':
                    // @ts-ignore
                    return { type: ParsedValueType.Px, value: value.value };
                case 'dip':
                    // @ts-ignore
                    return { type: ParsedValueType.Dip, value: value.value };
            }
        }
    }
    return { type: ParsedValueType.Auto, value: 0 };
}
export class ViewBase extends NSView {
    _addPropertyChangeHandler(view) {
        const style = view.style;
        style.on('flexChange', this._onPropertyChange, this);
        style.on('flexGrowChange', this._onPropertyChange, this);
        style.on('flexShrinkChange', this._onPropertyChange, this);
        style.on('flexWrapBeforeChange', this._onPropertyChange, this);
        style.on('alignSelfChange', this._onPropertyChange, this);
        style.on('orderChange', this._onPropertyChange, this);
    }
    _removePropertyChangeHandler(view) {
        const style = view.style;
        style.off('flexChange', this._onPropertyChange, this);
        style.off('flexGrowChange', this._onPropertyChange, this);
        style.off('flexShrinkChange', this._onPropertyChange, this);
        style.off('flexWrapBeforeChange', this._onPropertyChange, this);
        style.off('alignSelfChange', this._onPropertyChange, this);
        style.off('orderChange', this._onPropertyChange, this);
    }
    _onPropertyChange(data) {
        /* switch (data.propertyName) {
           case 'flexGrowChange':
             break;
           case 'flexShrinkChange':
             break;
           case 'flexWrapBeforeChange':
             break;
           case 'alignSelfChange':
             break;
         }
         */
    }
    _updateWidth(value, force = false, json = null, layout = null) {
        if (this.nativeView) {
            if (global.isAndroid) {
                const yg = toYGValue(value);
                switch (yg.type) {
                    case ParsedValueType.Auto:
                        if (json) {
                            json['width'] = 'auto';
                        }
                        else {
                            this.yogaNode.setWidthAuto();
                        }
                        break;
                    case ParsedValueType.Px:
                        if (json) {
                            json['width'] = `${yg.value}`;
                        }
                        else {
                            this.yogaNode.setWidth(yg.value);
                        }
                        break;
                    case ParsedValueType.Percent:
                        if (json) {
                            json['width'] = `${yg.value * 100}%`;
                        }
                        else {
                            this.yogaNode.setWidthPercent(yg.value * 100);
                        }
                        break;
                    case ParsedValueType.Dip:
                        if (json) {
                            json['width'] = `${nsLayout.toDevicePixels(yg.value)}`;
                        }
                        else {
                            this.yogaNode.setWidth(nsLayout.toDevicePixels(yg.value));
                        }
                        break;
                }
            }
            else if (global.isIOS) {
                (layout || this.nativeView.yoga).width = _toNativeYG(value);
                if (force) {
                    (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
                }
            }
        }
    }
    _updateHeight(value, force = false, json = null, layout = null) {
        if (this.nativeView) {
            if (global.isAndroid) {
                const yg = toYGValue(value);
                switch (yg.type) {
                    case ParsedValueType.Auto:
                        if (json) {
                            json['height'] = 'auto';
                        }
                        else {
                            this.yogaNode.setHeightAuto();
                        }
                        break;
                    case ParsedValueType.Px:
                        if (json) {
                            json['height'] = `${yg.value}`;
                        }
                        else {
                            this.yogaNode.setHeight(yg.value);
                        }
                        break;
                    case ParsedValueType.Percent:
                        if (json) {
                            json['height'] = `${yg.value * 100}%`;
                        }
                        else {
                            this.yogaNode.setHeightPercent(yg.value * 100);
                        }
                        break;
                    case ParsedValueType.Dip:
                        if (json) {
                            json['height'] = `${nsLayout.toDevicePixels(yg.value)}`;
                        }
                        else {
                            this.yogaNode.setHeight(nsLayout.toDevicePixels(yg.value));
                        }
                        break;
                }
            }
            else if (global.isIOS) {
                (layout || this.nativeView.yoga).height = _toNativeYG(value);
                if (force) {
                    (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
                }
            }
        }
    }
    _updateMinWidth(value, force = false, json = null, layout = null) {
        if (value !== 'none') {
            if (this.nativeView) {
                if (global.isAndroid) {
                    const yg = toYGValue(value);
                    switch (yg.type) {
                        case ParsedValueType.Auto:
                            break;
                        case ParsedValueType.Px:
                            if (json) {
                                json['minWidth'] = `${yg.value}`;
                            }
                            else {
                                this.yogaNode.setMinWidth(yg.value);
                            }
                            break;
                        case ParsedValueType.Percent:
                            if (json) {
                                json['minWidth'] = `${yg.value * 100}%`;
                            }
                            else {
                                this.yogaNode.setMinWidthPercent(yg.value * 100);
                            }
                            break;
                        case ParsedValueType.Dip:
                            if (json) {
                                json['minWidth'] = `${nsLayout.toDevicePixels(yg.value)}`;
                            }
                            else {
                                this.yogaNode.setMinWidth(nsLayout.toDevicePixels(yg.value));
                            }
                            break;
                    }
                }
                else if (global.isIOS) {
                    (layout || this.nativeView.yoga).minWidth = _toNativeYG(value);
                    if (force) {
                        (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
                    }
                }
            }
        }
    }
    _updateMinHeight(value, force = false, json = null, layout = null) {
        if (value !== 'none') {
            if (this.nativeView) {
                if (global.isAndroid) {
                    const yg = toYGValue(value);
                    switch (yg.type) {
                        case ParsedValueType.Auto:
                            break;
                        case ParsedValueType.Px:
                            if (json) {
                                json['minHeight'] = `${yg.value}`;
                            }
                            else {
                                this.yogaNode.setMinHeight(yg.value);
                            }
                            break;
                        case ParsedValueType.Percent:
                            if (json) {
                                json['minHeight'] = `${yg.value * 100}%`;
                            }
                            else {
                                this.yogaNode.setMinHeightPercent(yg.value * 100);
                            }
                            break;
                        case ParsedValueType.Dip:
                            if (json) {
                                json['minHeight'] = `${nsLayout.toDevicePixels(yg.value)}`;
                            }
                            else {
                                this.yogaNode.setMinHeight(nsLayout.toDevicePixels(yg.value));
                            }
                            break;
                    }
                }
                else if (global.isIOS) {
                    (layout || this.nativeView.yoga).minHeight = _toNativeYG(value);
                    if (force) {
                        (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
                    }
                }
            }
        }
    }
    _updateMaxWidth(value, force = false, json = null, layout = null) {
        if (value !== 'none') {
            if (this.nativeView) {
                if (global.isAndroid) {
                    const yg = toYGValue(value);
                    switch (yg.type) {
                        case ParsedValueType.Auto:
                            break;
                        case ParsedValueType.Px:
                            if (json) {
                                json['maxWidth'] = `${yg.value}`;
                            }
                            else {
                                this.yogaNode.setMaxWidth(yg.value);
                            }
                            break;
                        case ParsedValueType.Percent:
                            if (json) {
                                json['maxWidth'] = `${yg.value * 100}%`;
                            }
                            else {
                                this.yogaNode.setMaxWidthPercent(yg.value * 100);
                            }
                            break;
                        case ParsedValueType.Dip:
                            if (json) {
                                json['maxWidth'] = `${nsLayout.toDevicePixels(yg.value)}`;
                            }
                            else {
                                this.yogaNode.setMaxWidth(nsLayout.toDevicePixels(yg.value));
                            }
                            break;
                    }
                }
                else if (global.isIOS) {
                    (layout || this.nativeView.yoga).maxWidth = _toNativeYG(value);
                    if (force) {
                        (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
                    }
                }
            }
        }
    }
    _updateMaxHeight(value, force = false, json = null, layout = null) {
        if (value !== 'none') {
            if (this.nativeView) {
                if (global.isAndroid) {
                    const yg = toYGValue(value);
                    switch (yg.type) {
                        case ParsedValueType.Auto:
                            break;
                        case ParsedValueType.Px:
                            if (json) {
                                json['maxHeight'] = `${yg.value}`;
                            }
                            else {
                                this.yogaNode.setMaxHeight(yg.value);
                            }
                            break;
                        case ParsedValueType.Percent:
                            if (json) {
                                json['maxHeight'] = `${yg.value * 100}%`;
                            }
                            else {
                                this.yogaNode.setMaxHeightPercent(yg.value * 100);
                            }
                            break;
                        case ParsedValueType.Dip:
                            if (json) {
                                json['maxHeight'] = `${nsLayout.toDevicePixels(yg.value)}`;
                            }
                            else {
                                this.yogaNode.setMaxHeight(nsLayout.toDevicePixels(yg.value));
                            }
                            break;
                    }
                }
                else if (global.isIOS) {
                    (layout || this.nativeView.yoga).maxHeight = _toNativeYG(value);
                    if (force) {
                        (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
                    }
                }
            }
        }
    }
    _updateAlignItems(value, force = false, json = null, layout = null) {
        if (this.nativeView) {
            if (global.isAndroid) {
                if (json) {
                    json['alignItems'] = value;
                }
                else {
                    this.yogaNode.setAlignItems(_toYGFlexAlignItems(value));
                }
            }
            else if (global.isIOS) {
                (layout || this.nativeView.yoga).alignItems = _toYGFlexAlignItems(value);
                if (force) {
                    (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
                }
            }
        }
    }
    _updateOverflow(value, force = false, json = null, layout = null) {
        if (this.nativeView) {
            if (global.isAndroid) {
                if (json) {
                    json['overflow'] = value;
                }
                else {
                    this.yogaNode.setOverflow(_toYGOverflow(value));
                }
            }
            else if (global.isIOS) {
                (layout || this.nativeView.yoga).overflow = _toYGOverflow(value);
                if (force) {
                    (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
                }
            }
        }
    }
    _updatePosition(value, force = false, json = null, layout = null) {
        if (this.nativeView) {
            if (global.isAndroid) {
                if (json) {
                    json['position'] = value;
                }
                else {
                    this.yogaNode.setPositionType(_toYGPosition(value));
                }
            }
            else if (global.isIOS) {
                (layout || this.nativeView.yoga).position = _toYGPosition(value);
                if (force) {
                    (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
                }
            }
        }
    }
    _updateFlex(value, force = false, json = null, layout = null) {
        if (value === 1) {
            return;
        }
        if (this.nativeView) {
            if (global.isAndroid) {
                if (json) {
                    json['flex'] = value;
                }
                else {
                    this.yogaNode.setFlex(value);
                }
            }
            else if (global.isIOS) {
                (layout || this.nativeView.yoga).flex = value;
                if (force) {
                    (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
                }
            }
        }
    }
    _updateFlexDirection(value, force = false, json = null, layout = null) {
        if (this.nativeView) {
            if (global.isAndroid) {
                if (json) {
                    json['flexDirection'] = value;
                }
                else {
                    this.yogaNode.setFlexDirection(_toYGFlexDirection(value));
                }
            }
            else if (global.isIOS) {
                (layout || this.nativeView.yoga).flexDirection = _toYGFlexDirection(value);
                if (force) {
                    (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
                }
            }
        }
    }
    _setPositionValue(value, position, json = null, layout = null) {
        if (value === undefined || !this.nativeView || value === 'auto' || (value === null || value === void 0 ? void 0 : value.type) === 'auto') {
            return;
        }
        if (global.isAndroid) {
            const yg = toYGValue(value);
            switch (yg.type) {
                case ParsedValueType.Auto:
                    break;
                case ParsedValueType.Px:
                    if (json) {
                        json[position] = `${yg.value}`;
                    }
                    else {
                        this.nativeView.getYogaNode().setPosition(_toYGEdge(position), yg.value);
                    }
                    break;
                case ParsedValueType.Percent:
                    if (json) {
                        json[position] = `${yg.value * 100}%`;
                    }
                    else {
                        this.nativeView.getYogaNode().setPositionPercent(_toYGEdge(position), yg.value * 100);
                    }
                    break;
                case ParsedValueType.Dip:
                    if (json) {
                        json[position] = `${nsLayout.toDevicePixels(yg.value)}`;
                    }
                    else {
                        this.nativeView.getYogaNode().setPosition(_toYGEdge(position), nsLayout.toDevicePixels(yg.value));
                    }
                    break;
            }
        }
        else if (global.isIOS) {
            switch (position) {
                case 'left':
                    (layout || this.nativeView.yoga).left = _toNativeYG(value);
                    break;
                case 'top':
                    (layout || this.nativeView.yoga).top = _toNativeYG(value);
                    break;
                case 'right':
                    (layout || this.nativeView.yoga).right = _toNativeYG(value);
                    break;
                case 'bottom':
                    (layout || this.nativeView.yoga).bottom = _toNativeYG(value);
                    break;
                case 'start':
                    (layout || this.nativeView.yoga).start = _toNativeYG(value);
                    break;
                case 'end':
                    (layout || this.nativeView.yoga).end = _toNativeYG(value);
                    break;
                case 'vertical':
                    break;
                case 'horizontal':
                    break;
                case 'all':
                    break;
            }
        }
    }
    _getPositionValue(position, layout = null) {
        if (global.isAndroid) {
            const value = this.nativeView.getYogaNode().getPosition(_toYGEdge(position));
            switch (value.unit) {
                case com.facebook.yoga.YogaUnit.POINT:
                    return { value: value.value, unit: 'px' };
                case com.facebook.yoga.YogaUnit.PERCENT:
                    return { value: value.value / 100, unit: '%' };
                case com.facebook.yoga.YogaUnit.AUTO:
                    return 'auto';
                case com.facebook.yoga.YogaUnit.UNDEFINED:
                    return undefined;
            }
        }
        else if (global.isIOS) {
            const value = YGNodeStyleGetPosition((layout || this.nativeView.yoga), _toYGEdge(position));
            switch (value.unit) {
                case 1 /* Point */:
                    return { value: value.value, unit: 'px' };
                case 2 /* Percent */:
                    return { value: value.value / 100, unit: '%' };
                case 3 /* Auto */:
                    return 'auto';
                case 0 /* Undefined */:
                    return undefined;
            }
        }
    }
    _updateLeft(value, force = false, json = null, layout = null) {
        if (this.nativeView) {
            this._setPositionValue(value, 'left', json);
            if (global.isIOS) {
                (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
            }
        }
    }
    _updateTop(value, force = false, json = null, layout = null) {
        if (this.nativeView) {
            this._setPositionValue(value, 'top', json);
            if (global.isIOS) {
                (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
            }
        }
    }
    _updateRight(value, force = false, json = null, layout = null) {
        if (this.nativeView) {
            this._setPositionValue(value, 'right', json);
            if (global.isIOS) {
                (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
            }
        }
    }
    _updateBottom(value, force = false, json = null, layout = null) {
        if (this.nativeView) {
            this._setPositionValue(value, 'bottom', json);
            if (global.isIOS) {
                (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
            }
        }
    }
    _setPaddingValue(value, position, json = null, layout = null) {
        if (value === undefined || !this.yogaNode || value === 'auto' || (value === null || value === void 0 ? void 0 : value.type) === 'auto') {
            return;
        }
        if (global.isAndroid) {
            const yg = toYGValue(value);
            const unit = yg.type === ParsedValueType.Percent ? '%' : '';
            let padding = 0;
            switch (yg.type) {
                case ParsedValueType.Auto:
                    break;
                case ParsedValueType.Px:
                    if (json) {
                        padding = yg.value;
                    }
                    else {
                        this.yogaNode.setPadding(_toYGEdge(position), yg.value);
                    }
                    break;
                case ParsedValueType.Percent:
                    if (json) {
                        padding = yg.value * 100;
                    }
                    else {
                        this.yogaNode.setPaddingPercent(_toYGEdge(position), yg.value * 100);
                    }
                    break;
                case ParsedValueType.Dip:
                    if (json) {
                        padding = nsLayout.toDevicePixels(yg.value);
                    }
                    else {
                        this.yogaNode.setPadding(_toYGEdge(position), nsLayout.toDevicePixels(yg.value));
                    }
                    break;
            }
            if (json) {
                if (position === 'all') {
                    json['paddingLeft'] = `${padding}${unit}`;
                    json['paddingTop'] = `${padding}${unit}`;
                    json['paddingRight'] = `${padding}${unit}`;
                    json['paddingBottom'] = `${padding}${unit}`;
                }
                else {
                    json[`padding${firstCharToUpperCase(position)}`] = `${padding}${unit}`;
                }
            }
        }
        else if (global.isIOS) {
            switch (position) {
                case 'left':
                    (layout || this.nativeView.yoga).paddingLeft = _toNativeYG(value);
                    break;
                case 'top':
                    (layout || this.nativeView.yoga).paddingTop = _toNativeYG(value);
                    break;
                case 'right':
                    (layout || this.nativeView.yoga).paddingRight = _toNativeYG(value);
                    break;
                case 'bottom':
                    (layout || this.nativeView.yoga).paddingBottom = _toNativeYG(value);
                    break;
                case 'start':
                    (layout || this.nativeView.yoga).paddingStart = _toNativeYG(value);
                    break;
                case 'end':
                    (layout || this.nativeView.yoga).paddingEnd = _toNativeYG(value);
                    break;
                case 'vertical':
                    (layout || this.nativeView.yoga).paddingVertical = _toNativeYG(value);
                    break;
                case 'horizontal':
                    (layout || this.nativeView.yoga).paddingHorizontal = _toNativeYG(value);
                    break;
                case 'all':
                    (layout || this.nativeView.yoga).padding = _toNativeYG(value);
                    break;
            }
        }
    }
    _getPaddingValue(position, layout = null) {
        if (global.isAndroid) {
            const value = this.yogaNode.getPadding(_toYGEdge(position));
            switch (value.unit) {
                case com.facebook.yoga.YogaUnit.POINT:
                    return { value: value.value, unit: 'px' };
                case com.facebook.yoga.YogaUnit.PERCENT:
                    return { value: value.value / 100, unit: '%' };
                case com.facebook.yoga.YogaUnit.AUTO:
                    return 'auto';
                case com.facebook.yoga.YogaUnit.UNDEFINED:
                    return undefined;
            }
        }
        else if (global.isIOS) {
            const value = YGNodeStyleGetPosition((layout || this.nativeView.yoga), _toYGEdge(position));
            switch (value.unit) {
                case 1 /* Point */:
                    return { value: value.value, unit: 'px' };
                case 2 /* Percent */:
                    return { value: value.value / 100, unit: '%' };
                case 3 /* Auto */:
                    return 'auto';
                case 0 /* Undefined */:
                    return undefined;
            }
        }
    }
    _updatePadding(value, force = false, json = null, layout = null) {
        if (this.nativeView) {
            this._setPaddingValue(value, 'all', json);
            if (global.isIOS) {
                (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
            }
        }
    }
    _updatePaddingLeft(value, force = false, json = null, layout = null) {
        if (this.nativeView) {
            this._setPaddingValue(value, 'left', json);
            if (global.isIOS) {
                (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
            }
        }
    }
    _updatePaddingTop(value, force = false, json = null, layout = null) {
        if (this.nativeView) {
            this._setPaddingValue(value, 'top', json);
            if (global.isIOS) {
                (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
            }
        }
    }
    _updatePaddingRight(value, force = false, json = null, layout = null) {
        if (this.nativeView) {
            this._setPaddingValue(value, 'right', json);
            if (global.isIOS) {
                (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
            }
        }
    }
    _updatePaddingBottom(value, force = false, json = null, layout = null) {
        if (this.nativeView) {
            this._setPaddingValue(value, 'bottom', json);
            if (global.isIOS) {
                (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
            }
        }
    }
    _setMarginValue(value, position, json = null, layout = null) {
        if (!this.yogaNode || value === undefined || value === 'auto' || (value === null || value === void 0 ? void 0 : value.type) === 'auto') {
            return;
        }
        if (global.isAndroid) {
            const yg = toYGValue(value);
            const unit = yg.type === ParsedValueType.Percent ? '%' : '';
            let margin = 0;
            switch (yg.type) {
                case ParsedValueType.Auto:
                    break;
                case ParsedValueType.Px:
                    if (json) {
                        margin = yg.value;
                    }
                    else {
                        this.yogaNode.setMargin(_toYGEdge(position), yg.value);
                    }
                    break;
                case ParsedValueType.Percent:
                    if (json) {
                        margin = yg.value * 100;
                    }
                    else {
                        this.yogaNode.setMarginPercent(_toYGEdge(position), yg.value * 100);
                    }
                    break;
                case ParsedValueType.Dip:
                    if (json) {
                        margin = nsLayout.toDevicePixels(yg.value);
                    }
                    else {
                        this.yogaNode.setMargin(_toYGEdge(position), nsLayout.toDevicePixels(yg.value));
                    }
                    break;
            }
            if (json) {
                if (position === 'all') {
                    json['marginLeft'] = `${margin}${unit}`;
                    json['marginTop'] = `${margin}${unit}`;
                    json['marginRight'] = `${margin}${unit}`;
                    json['marginBottom'] = `${margin}${unit}`;
                }
                else {
                    json[`margin${firstCharToUpperCase(position)}`] = `${margin}${unit}`;
                }
            }
        }
        else if (global.isIOS) {
            if (value === undefined || value === 'auto' || (value === null || value === void 0 ? void 0 : value.type) === 'auto') {
                return;
            }
            switch (position) {
                case 'left':
                    (layout || this.nativeView.yoga).marginLeft = _toNativeYG(value);
                    break;
                case 'top':
                    (layout || this.nativeView.yoga).marginTop = _toNativeYG(value);
                    break;
                case 'right':
                    (layout || this.nativeView.yoga).marginRight = _toNativeYG(value);
                    break;
                case 'bottom':
                    (layout || this.nativeView.yoga).marginBottom = _toNativeYG(value);
                    break;
                case 'start':
                    (layout || this.nativeView.yoga).marginStart = _toNativeYG(value);
                    break;
                case 'end':
                    (layout || this.nativeView.yoga).marginEnd = _toNativeYG(value);
                    break;
                case 'vertical':
                    (layout || this.nativeView.yoga).marginVertical = _toNativeYG(value);
                    break;
                case 'horizontal':
                    (layout || this.nativeView.yoga).marginHorizontal = _toNativeYG(value);
                    break;
                case 'all':
                    (layout || this.nativeView.yoga).margin = _toNativeYG(value);
                    break;
            }
        }
    }
    _getMarginValue(position, layout = null) {
        if (global.isAndroid) {
            const value = this.nativeView.getYogaNode().getMargin(_toYGEdge(position));
            switch (value.unit) {
                case com.facebook.yoga.YogaUnit.POINT:
                    return { value: value.value, unit: 'px' };
                case com.facebook.yoga.YogaUnit.PERCENT:
                    return { value: value.value / 100, unit: '%' };
                case com.facebook.yoga.YogaUnit.AUTO:
                    return 'auto';
                case com.facebook.yoga.YogaUnit.UNDEFINED:
                    return undefined;
            }
        }
        else if (global.isIOS) {
            const value = YGNodeStyleGetPosition((layout || this.nativeView.yoga), _toYGEdge(position));
            switch (value.unit) {
                case 1 /* Point */:
                    return { value: value.value, unit: 'px' };
                case 2 /* Percent */:
                    return { value: value.value / 100, unit: '%' };
                case 3 /* Auto */:
                    return 'auto';
                case 0 /* Undefined */:
                    return undefined;
            }
        }
    }
    _updateMargin(value, force = false, json = null, layout = null) {
        if (this.nativeView) {
            this._setMarginValue(value, 'all', json);
            if (global.isIOS) {
                (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
            }
        }
    }
    _updateMarginLeft(value, force = false, json = null, layout = null) {
        if (this.nativeView) {
            this._setMarginValue(value, 'left', json);
            if (global.isIOS) {
                (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
            }
        }
    }
    _updateMarginTop(value, force = false, json = null, layout = null) {
        if (this.nativeView) {
            this._setMarginValue(value, 'top', json);
            if (global.isIOS) {
                (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
            }
        }
    }
    _updateMarginRight(value, force = false, json = null, layout = null) {
        if (this.nativeView) {
            this._setMarginValue(value, 'right', json);
            if (global.isIOS) {
                (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
            }
        }
    }
    _updateMarginBottom(value, force = false, json = null, layout = null) {
        if (this.nativeView) {
            this._setMarginValue(value, 'bottom', json);
            if (global.isIOS) {
                (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
            }
        }
    }
    _updateJustifyContent(value, force = false, json = null, layout = null) {
        if (this.nativeView) {
            if (global.isAndroid) {
                if (json) {
                    json['justifyContent'] = value;
                }
                else {
                    switch (value) {
                        case FlexJustify.FlexStart:
                            this.nativeView.getYogaNode().setJustifyContent(com.facebook.yoga.YogaJustify.FLEX_START);
                            break;
                        case FlexJustify.FlexEnd:
                            this.nativeView.getYogaNode().setJustifyContent(com.facebook.yoga.YogaJustify.FLEX_END);
                            break;
                        case FlexJustify.Center:
                            this.nativeView.getYogaNode().setJustifyContent(com.facebook.yoga.YogaJustify.CENTER);
                            break;
                        case FlexJustify.SpaceAround:
                            this.nativeView.getYogaNode().setJustifyContent(com.facebook.yoga.YogaJustify.SPACE_AROUND);
                            break;
                        case FlexJustify.SpaceBetween:
                            this.nativeView.getYogaNode().setJustifyContent(com.facebook.yoga.YogaJustify.SPACE_BETWEEN);
                            break;
                        case FlexJustify.SpaceEvenly:
                            this.nativeView.getYogaNode().setJustifyContent(com.facebook.yoga.YogaJustify.SPACE_EVENLY);
                            break;
                    }
                }
            }
            else if (global.isIOS) {
                switch (value) {
                    case FlexJustify.FlexStart:
                        (layout || this.nativeView.yoga).justifyContent = 0 /* FlexStart */;
                        break;
                    case FlexJustify.FlexEnd:
                        (layout || this.nativeView.yoga).justifyContent = 2 /* FlexEnd */;
                        break;
                    case FlexJustify.Center:
                        (layout || this.nativeView.yoga).justifyContent = 1 /* Center */;
                        break;
                    case FlexJustify.SpaceAround:
                        (layout || this.nativeView.yoga).justifyContent = 4 /* SpaceAround */;
                        break;
                    case FlexJustify.SpaceBetween:
                        (layout || this.nativeView.yoga).justifyContent = 3 /* SpaceBetween */;
                        break;
                    case FlexJustify.SpaceEvenly:
                        (layout || this.nativeView.yoga).justifyContent = 5 /* SpaceEvenly */;
                        break;
                }
                if (force) {
                    (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
                }
            }
        }
    }
    _updateFlexWrap(value, force = false, json = null, layout = null) {
        if (this.nativeView) {
            if (global.isAndroid) {
                if (json) {
                    json['flexWrap'] = value;
                }
                else {
                    switch (value) {
                        case FlexWrap.NoWrap:
                            this.nativeView.getYogaNode().setWrap(com.facebook.yoga.YogaWrap.NO_WRAP);
                            break;
                        case FlexWrap.Wrap:
                            this.nativeView.getYogaNode().setWrap(com.facebook.yoga.YogaWrap.WRAP);
                            break;
                        case FlexWrap.WrapReverse:
                            this.nativeView.getYogaNode().setWrap(com.facebook.yoga.YogaWrap.WRAP_REVERSE);
                            break;
                    }
                }
            }
            else if (global.isIOS) {
                switch (value) {
                    case FlexWrap.NoWrap:
                        (layout || this.nativeView.yoga).flexWrap = 0 /* NoWrap */;
                        break;
                    case FlexWrap.Wrap:
                        (layout || this.nativeView.yoga).flexWrap = 1 /* Wrap */;
                        break;
                    case FlexWrap.WrapReverse:
                        (layout || this.nativeView.yoga).flexWrap = 2 /* WrapReverse */;
                        break;
                }
                if (force) {
                    (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
                }
            }
        }
    }
    _updateAlignSelf(value, force = false, json = null, layout = null) {
        if (this.nativeView) {
            if (global.isAndroid) {
                if (json) {
                    json['alignSelf'] = value;
                }
                else {
                    this.yogaNode.setAlignSelf(_toYGFlexAlignSelf(value));
                }
            }
            else if (global.isIOS) {
                (layout || this.nativeView.yoga).alignSelf = _toYGFlexAlignSelf(value);
                if (force) {
                    (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
                }
            }
        }
    }
    _updateFlexGrow(value, force = false, json = null, layout = null) {
        if (this.nativeView) {
            if (global.isAndroid) {
                if (json) {
                    json['flexGrow'] = value;
                }
                else {
                    this.yogaNode.setFlexGrow(value);
                }
            }
            else if (global.isIOS) {
                if ((layout || this.nativeView.yoga).flexGrow === value) {
                    return;
                }
                (layout || this.nativeView.yoga).flexGrow = value;
                if (force) {
                    (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
                }
            }
        }
    }
    _updateFlexShrink(value, force = false, json = null, layout = null) {
        if (this.nativeView) {
            if (global.isAndroid) {
                if (json) {
                    json['flexShrink'] = value;
                }
                else {
                    this.yogaNode.setFlexShrink(value);
                }
            }
            else if (global.isIOS) {
                if ((layout || this.nativeView.yoga).flexShrink === value) {
                    return;
                }
                (layout || this.nativeView.yoga).flexShrink = value;
                if (force) {
                    (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
                }
            }
        }
    }
    _updateFlexBasis(value, force = false, json = null, layout = null) {
        if (this.nativeView) {
            if (global.isAndroid) {
                const yg = toYGValue(value);
                switch (yg.type) {
                    case ParsedValueType.Auto:
                        if (json) {
                            json['flexBasis'] = 'auto';
                        }
                        else {
                            this.yogaNode.setFlexBasisAuto();
                        }
                        break;
                    case ParsedValueType.Px:
                        if (json) {
                            json['flexBasis'] = `${yg.value}`;
                        }
                        else {
                            this.yogaNode.setFlexBasis(yg.value);
                        }
                        break;
                    case ParsedValueType.Percent:
                        if (json) {
                            json['flexBasis'] = `${yg.value * 100}%`;
                        }
                        else {
                            this.yogaNode.setFlexBasisPercent(yg.value * 100);
                        }
                        break;
                    case ParsedValueType.Dip:
                        if (json) {
                            json['flexBasis'] = `${nsLayout.toDevicePixels(yg.value)}`;
                        }
                        else {
                            this.yogaNode.setFlexBasis(nsLayout.toDevicePixels(yg.value));
                        }
                        break;
                }
            }
            else if (global.isIOS) {
                if ((layout || this.nativeView.yoga).flexBasis === value) {
                    return;
                }
                (layout || this.nativeView.yoga).flexBasis = _toNativeYG(value);
                if (force) {
                    (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
                }
            }
        }
    }
    _updateAlignContent(value, force = false, json = null, layout = null) {
        if (!value) {
            return;
        }
        if (this.nativeView) {
            if (global.isAndroid) {
                if (json) {
                    json['alignContent'] = value;
                }
                else {
                    this.yogaNode.setAlignContent(_toYGFlexAlignContent(value));
                }
            }
            else if (global.isIOS) {
                (layout || this.nativeView.yoga).alignContent = _toYGFlexAlignContent(value);
                if (force) {
                    (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
                }
            }
        }
    }
    _updateAspectRatio(value, force = false, json = null, layout = null) {
        if (typeof value !== 'number')
            return;
        if (this.nativeView) {
            if (global.isAndroid) {
                if (json) {
                    json['aspectRatio'] = value;
                }
                else {
                    this.yogaNode.setAspectRatio(value);
                }
            }
            else if (global.isIOS) {
                (layout || this.nativeView.yoga).aspectRatio = value;
                if (force) {
                    (layout || this.nativeView.yoga).applyLayoutPreservingOrigin(true);
                }
            }
        }
    }
    _setStartOrEnd(value, position, force = false, json = null, layout = null) {
        if (this.nativeView) {
            let direction;
            if (global.isAndroid) {
                direction = io.github.triniwiz.yogalayout.Utils.getLayoutDirection(this.yogaNode);
            }
            else if (global.isIOS) {
                direction = (layout || this.nativeView).direction;
            }
            switch (direction) {
                case 'rtl':
                    if (position === 'start') {
                        this._updateRight(value, force, json, layout);
                    }
                    if (position === 'end') {
                        this._updateLeft(value, force, json, layout);
                    }
                    break;
                case 'ltr':
                    if (position === 'start') {
                        this._updateLeft(value, force, json, layout);
                    }
                    if (position === 'end') {
                        this._updateRight(value, force, json, layout);
                    }
                    break;
            }
        }
    }
    _updateStart(value, force = false, json = null, layout = null) {
        this._setStartOrEnd(value, 'start', force, json, layout);
    }
    _updateEnd(value, force = false, json = null, layout = null) {
        this._setStartOrEnd(value, 'end', force, json, layout);
    }
    _updateDirection(value, force = false, json = null, layout = null) {
        if (!value) {
            return;
        }
        if (this.nativeView) {
            if (global.isAndroid) {
                if (json) {
                    json['direction'] = value;
                }
                else {
                    this.yogaNode.setDirection(_toYGDirection(value));
                }
            }
            else if (global.isIOS) {
                (layout || this.nativeView.yoga).direction = _toYGDirection(value);
            }
        }
    }
    _updateMarginVertical(value, force = false, json = null, layout = null) {
        this._setMarginValue(value, 'vertical', json, layout);
    }
    _updateMarginHorizontal(value, force = false, json = null, layout = null) {
        this._setMarginValue(value, 'horizontal', json, layout);
    }
    _updatePaddingHorizontal(value, force = false, json = null, layout = null) {
        this._setPaddingValue(value, 'horizontal', json, layout);
    }
    _updatePaddingVertical(value, force = false, json = null, layout = null) {
        this._setPaddingValue(value, 'vertical', json, layout);
    }
}
export const minWidthProperty = new CssProperty({
    name: 'minWidth',
    cssName: 'min-width',
    defaultValue: 'none',
});
minWidthProperty.register(Style);
export const minHeightProperty = new CssProperty({
    name: 'minHeight',
    cssName: 'min-height',
    defaultValue: 'none',
});
minHeightProperty.register(Style);
export const maxWidthProperty = new CssProperty({
    name: 'maxWidth',
    cssName: 'max-width',
    defaultValue: 'none',
});
maxWidthProperty.register(Style);
export const maxHeightProperty = new CssProperty({
    name: 'maxHeight',
    cssName: 'max-height',
    defaultValue: 'none',
});
maxHeightProperty.register(Style);
export const flexProperty = new CssProperty({
    name: 'flex',
    cssName: 'flex',
    defaultValue: 1.0,
    valueConverter: (val) => Number(val),
});
flexProperty.register(Style);
export const flexDirectionProperty = new CssProperty({
    name: 'flexDirection',
    cssName: 'flex-direction',
    defaultValue: FlexDirection.Row,
});
flexDirectionProperty.register(Style);
export const flexGrowProperty = new CssProperty({
    name: 'flexGrow',
    cssName: 'flex-grow',
    defaultValue: 0,
    valueConverter: (val) => Number(val),
});
flexGrowProperty.register(Style);
export const flexShrinkProperty = new CssProperty({
    name: 'flexShrink',
    cssName: 'flex-shrink',
    defaultValue: 1,
    valueConverter: (val) => Number(val),
});
flexShrinkProperty.register(Style);
export const flexBasisProperty = new CssProperty({
    name: 'flexBasis',
    cssName: 'flex-basis',
    defaultValue: 'auto',
});
flexBasisProperty.register(Style);
export const alignContentProperty = new CssProperty({
    name: 'alignContent',
    cssName: 'align-content',
});
alignContentProperty.register(Style);
export const alignItemsProperty = new CssProperty({
    name: 'alignItems',
    cssName: 'align-items',
    defaultValue: FlexAlignItems.Stretch,
});
alignItemsProperty.register(Style);
export const alignSelfProperty = new CssProperty({
    name: 'alignSelf',
    cssName: 'align-self',
    defaultValue: FlexAlignSelf.Auto,
});
alignSelfProperty.register(Style);
export const overflowProperty = new CssProperty({
    name: 'overflow',
    cssName: 'overflow',
    defaultValue: Overflow.Visible,
});
overflowProperty.register(Style);
export const positionProperty = new CssProperty({
    name: 'position',
    cssName: 'position',
    defaultValue: Position.Relative,
});
positionProperty.register(Style);
export const leftProperty = new CssProperty({
    name: 'left',
    cssName: 'left',
});
leftProperty.register(Style);
export const topProperty = new CssProperty({
    name: 'top',
    cssName: 'top',
});
topProperty.register(Style);
export const rightProperty = new CssProperty({
    name: 'right',
    cssName: 'right',
});
rightProperty.register(Style);
export const bottomProperty = new CssProperty({
    name: 'bottom',
    cssName: 'bottom',
});
bottomProperty.register(Style);
export const justifyContentProperty = new CssProperty({
    name: 'justifyContent',
    cssName: 'justify-content',
    defaultValue: FlexJustify.FlexStart,
});
justifyContentProperty.register(Style);
export const flexWrapProperty = new CssProperty({
    name: 'flexWrap',
    cssName: 'flex-wrap',
    defaultValue: FlexWrap.NoWrap,
});
flexWrapProperty.register(Style);
export const aspectRatioProperty = new Property({
    name: 'aspectRatio',
});
aspectRatioProperty.register(ViewBase);
export const endProperty = new CssProperty({
    name: 'end',
    cssName: 'end',
});
endProperty.register(Style);
export const startProperty = new CssProperty({
    name: 'start',
    cssName: 'start',
});
startProperty.register(Style);
export const directionProperty = new CssProperty({
    name: 'direction',
    cssName: 'direction',
    defaultValue: Direction.Inherit,
});
directionProperty.register(Style);
export const paddingHorizontalProperty = new CssProperty({
    name: 'paddingHorizontal',
    cssName: 'padding-horizontal',
});
paddingHorizontalProperty.register(Style);
export const paddingVerticalProperty = new CssProperty({
    name: 'paddingVertical',
    cssName: 'padding-vertical',
});
paddingVerticalProperty.register(Style);
export const marginHorizontalProperty = new CssProperty({
    name: 'marginHorizontal',
    cssName: 'margin-horizontal',
});
marginHorizontalProperty.register(Style);
export const marginVerticalProperty = new CssProperty({
    name: 'marginVertical',
    cssName: 'margin-vertical',
});
marginVerticalProperty.register(Style);
export function _toYGFlexDirection(value) {
    if (global.isIOS) {
        switch (value) {
            case FlexDirection.Row:
                return 2 /* Row */;
            case FlexDirection.Column:
                return 0 /* Column */;
            case FlexDirection.ColumnReverse:
                return 1 /* ColumnReverse */;
            case FlexDirection.RowReverse:
                return 3 /* RowReverse */;
        }
    }
    else if (global.isAndroid) {
        switch (value) {
            case FlexDirection.Row:
                return com.facebook.yoga.YogaFlexDirection.ROW;
            case FlexDirection.Column:
                return com.facebook.yoga.YogaFlexDirection.COLUMN;
            case FlexDirection.ColumnReverse:
                return com.facebook.yoga.YogaFlexDirection.COLUMN_REVERSE;
            case FlexDirection.RowReverse:
                return com.facebook.yoga.YogaFlexDirection.ROW_REVERSE;
        }
    }
}
export function _toYGFlexAlignSelf(value) {
    if (global.isIOS) {
        switch (value) {
            case FlexAlignSelf.Stretch:
                return 4 /* Stretch */;
            case FlexAlignSelf.Center:
                return 2 /* Center */;
            case FlexAlignSelf.FlexEnd:
                return 3 /* FlexEnd */;
            case FlexAlignSelf.FlexStart:
                return 1 /* FlexStart */;
            case FlexAlignSelf.BaseLine:
                return 5 /* Baseline */;
            case FlexAlignSelf.Auto:
                return 0 /* Auto */;
        }
    }
    else if (global.isAndroid) {
        switch (value) {
            case FlexAlignSelf.Stretch:
                return com.facebook.yoga.YogaAlign.STRETCH;
            case FlexAlignSelf.Center:
                return com.facebook.yoga.YogaAlign.CENTER;
            case FlexAlignSelf.FlexEnd:
                return com.facebook.yoga.YogaAlign.FLEX_END;
            case FlexAlignSelf.FlexStart:
                return com.facebook.yoga.YogaAlign.FLEX_START;
            case FlexAlignSelf.BaseLine:
                return com.facebook.yoga.YogaAlign.BASELINE;
            case FlexAlignSelf.Auto:
                return com.facebook.yoga.YogaAlign.BASELINE;
        }
    }
}
export function _toYGFlexAlignItems(value) {
    if (global.isIOS) {
        switch (value) {
            case FlexAlignItems.Stretch:
                return 4 /* Stretch */;
            case FlexAlignItems.Center:
                return 2 /* Center */;
            case FlexAlignItems.FlexEnd:
                return 3 /* FlexEnd */;
            case FlexAlignItems.FlexStart:
                return 1 /* FlexStart */;
            case FlexAlignItems.BaseLine:
                return 5 /* Baseline */;
        }
    }
    else if (global.isAndroid) {
        switch (value) {
            case FlexAlignItems.Stretch:
                return com.facebook.yoga.YogaAlign.STRETCH;
            case FlexAlignItems.Center:
                return com.facebook.yoga.YogaAlign.CENTER;
            case FlexAlignItems.FlexEnd:
                return com.facebook.yoga.YogaAlign.FLEX_END;
            case FlexAlignItems.FlexStart:
                return com.facebook.yoga.YogaAlign.FLEX_START;
            case FlexAlignItems.BaseLine:
                return com.facebook.yoga.YogaAlign.BASELINE;
        }
    }
}
export function _toYGOverflow(value) {
    if (global.isIOS) {
        switch (value) {
            case Overflow.Visible:
                return 0 /* Visible */;
            case Overflow.Hidden:
                return 1 /* Hidden */;
            case Overflow.Scroll:
                return 2 /* Scroll */;
        }
    }
    else if (global.isAndroid) {
        switch (value) {
            case Overflow.Visible:
                return com.facebook.yoga.YogaOverflow.VISIBLE;
            case Overflow.Hidden:
                return com.facebook.yoga.YogaOverflow.HIDDEN;
            case Overflow.Scroll:
                return com.facebook.yoga.YogaOverflow.SCROLL;
        }
    }
}
export function _toYGPosition(value) {
    if (global.isIOS) {
        switch (value) {
            case Position.Absolute:
                return 1 /* Absolute */;
            default:
                return 0 /* Relative */;
        }
    }
    else if (global.isAndroid) {
        switch (value) {
            case Position.Absolute:
                return com.facebook.yoga.YogaPositionType.ABSOLUTE;
            default:
                return com.facebook.yoga.YogaPositionType.RELATIVE;
        }
    }
}
export function _toNativeYG(value) {
    const yg = toYGValue(value);
    switch (yg.type) {
        case ParsedValueType.Auto:
            return YGValueAuto;
        case ParsedValueType.Px:
            return { value: yg.value, unit: 1 /* Point */ };
        case ParsedValueType.Percent:
            return YGPercentValue(yg.value);
        case ParsedValueType.Dip:
            return YGPointValue(yg.value);
    }
    return YGValueZero;
}
export function _toYGEdge(value) {
    if (global.isIOS) {
        switch (value) {
            case 'left':
                return 0 /* Left */;
            case 'top':
                return 1 /* Top */;
            case 'right':
                return 2 /* Right */;
            case 'bottom':
                return 3 /* Bottom */;
            case 'start':
                return 4 /* Start */;
            case 'end':
                return 5 /* End */;
            case 'vertical':
                return 7 /* Vertical */;
            case 'horizontal':
                return 6 /* Horizontal */;
            case 'all':
                return 8 /* All */;
        }
    }
    else if (global.isAndroid) {
        switch (value) {
            case 'left':
                return com.facebook.yoga.YogaEdge.LEFT;
            case 'top':
                return com.facebook.yoga.YogaEdge.TOP;
            case 'right':
                return com.facebook.yoga.YogaEdge.RIGHT;
            case 'bottom':
                return com.facebook.yoga.YogaEdge.BOTTOM;
            case 'start':
                return com.facebook.yoga.YogaEdge.START;
            case 'end':
                return com.facebook.yoga.YogaEdge.END;
            case 'vertical':
                return com.facebook.yoga.YogaEdge.VERTICAL;
            case 'horizontal':
                return com.facebook.yoga.YogaEdge.HORIZONTAL;
            case 'all':
                return com.facebook.yoga.YogaEdge.ALL;
        }
    }
}
export function _toYGFlexAlignContent(value) {
    if (global.isIOS) {
        switch (value) {
            case FlexAlignContent.Stretch:
                return 4 /* Stretch */;
            case FlexAlignContent.Center:
                return 2 /* Center */;
            case FlexAlignContent.FlexEnd:
                return 3 /* FlexEnd */;
            case FlexAlignContent.FlexStart:
                return 1 /* FlexStart */;
            case FlexAlignContent.SpaceAround:
                return 7 /* SpaceAround */;
            case FlexAlignContent.SpaceBetween:
                return 6 /* SpaceBetween */;
        }
    }
    else if (global.isAndroid) {
        switch (value) {
            case FlexAlignContent.Stretch:
                return com.facebook.yoga.YogaAlign.STRETCH;
            case FlexAlignContent.Center:
                return com.facebook.yoga.YogaAlign.CENTER;
            case FlexAlignContent.FlexEnd:
                return com.facebook.yoga.YogaAlign.FLEX_END;
            case FlexAlignContent.FlexStart:
                return com.facebook.yoga.YogaAlign.FLEX_START;
            case FlexAlignContent.SpaceBetween:
                return com.facebook.yoga.YogaAlign.SPACE_BETWEEN;
            case FlexAlignContent.SpaceAround:
                return com.facebook.yoga.YogaAlign.SPACE_AROUND;
        }
    }
}
function firstCharToUpperCase(value) {
    return value.charAt(0).toUpperCase() + value.slice(1);
}
export function _toYGDirection(value) {
    if (global.isAndroid) {
        switch (value) {
            case Direction.Rtl:
                return com.facebook.yoga.YogaDirection.RTL;
            case Direction.Ltr:
                return com.facebook.yoga.YogaDirection.LTR;
            default:
                return com.facebook.yoga.YogaDirection.INHERIT;
        }
    }
    else if (global.isIOS) {
        switch (value) {
            case Direction.Rtl:
                return 2 /* RTL */;
            case Direction.Ltr:
                return 1 /* LTR */;
            default:
                return 0 /* Inherit */;
        }
    }
}
//# sourceMappingURL=common.js.map